#!/bin/sh
#
# CA Technologies --- script based on DXserver/samples/democorp
#
# Description:
#   This script configures the SiteMinder Key Store DSA.
#

thishost=`hostname`
quiet=n
dsaname=smKeyStore
dsaport=14321
consoleport=14322

usage()
{
    echo
    echo "Usage:"
    echo "    '$0' [-q]"
    echo
    exit 1
}

# Command Failed
fail()
{
    echo
    echo " Error running '$1', $dsaname Setup Failed."  | tee /tmp/status 
    echo
    exit 1
}

if [ -z "$DXHOME" ]; then
    echo "  You must be the DXserver Administrator to run this script"
    exit 1
fi

if [ ! -f "$DXHOME/config/schema/SiteMinder.dxg" ]; then
    echo "  SiteMinder schema group file Siteminder.dxg not found in $DXHOME/config/schema folder"
    fail check_SiteMinder.dxg
fi

if [ "$1" = "-q" -o "$2" = "-q" ]; then
    quiet=y
fi

#clear
echo
echo " $dsaname - CA Directory configuration"
echo " ------------------------------------------"
echo
echo " This script will perform the following steps:"
echo
echo "   * Configure the $dsaname initialization file ($dsaname.dxi)"
echo "   * Configure the $dsaname knowledge file ($dsaname.dxc)"
echo "   * Configure the $dsaname limits file ($dsaname.dxc)"
echo "   * Populate the SiteMinder Key Store base tree structure"	

if [ "$quiet" = "n" ]; then
    echo Press RETURN to continue . . .
    read TMP
fi

#
# Stop and remove $dsaname
#

dxserver stop $dsaname >/dev/null 2>&1

dxserver remove $dsaname >/dev/null 2>&1

#
# Build the DSA configuration files
#

    #clear
    echo
    echo " Configuring the $dsaname initialization file"
    echo " --------------------------------------------"
    echo
    echo "   The $dsaname initialization file $dsaname.dxi resides in the directory:"
    echo
    echo "     $DXHOME/config/servers/"
    echo
    echo "   Writing the $dsaname initialization file..."

    rm -f $dsaname.dxi
    cat << EOF > $dsaname.dxi
# CA Technologies DXserver/config/servers
#
# $dsaname.dxi written by script based on samples/democorp/setup.sh
#
# SiteMinder Key Store initialization file.
#

# logging and tracing
source "../logging/default.dxc";

# schema
source "../schema/SiteMinder.dxg";

# knowledge
clear dsas;
source "../knowledge/$dsaname.dxc";

# operational settings
source "../settings/default.dxc";

# service limits
source "../limits/$dsaname.dxc";

# access controls
clear access;
source "../access/default.dxc";

# ssl
source "../ssld/default.dxc";

# replication agreements (rarely used)
# source "../replication/";

# multiwrite DISP recovery
set multi-write-disp-recovery = false;

# grid configuration
set dxgrid-db-location = "data";
set dxgrid-db-size = 50;
set cache-index = all-attributes;
set lookup-cache = true;

# cache configuration
set ignore-name-bindings = true;
EOF

    echo "   $dsaname initialization file written"
    echo "   Moving the $dsaname initialization file to the servers directory..."
    mv $dsaname.dxi $DXHOME/config/servers/
    echo
    echo " Completed - $dsaname initialization file configured"
    echo
    if [ "$quiet" = "n" ]; then
        echo Press RETURN to continue . . .
        read TMP 
    fi

    #clear
    echo
    echo " Configuring the $dsaname knowledge file"
    echo " ---------------------------------------"
    echo
    echo "   The $dsaname knowledge file $dsaname.dxc resides in the directory:"
    echo
    echo "     $DXHOME/config/knowledge/"
    echo
    echo "   This will be edited to contain this machine's hostname."
    echo
    echo "   Writing the $dsaname knowledge file..."

    rm -f $dsaname.dxc
    cat << EOF > $dsaname.dxc
# CA Technologies DXserver/config/knowledge
#
# $dsaname.dxc written by script based on samples/democorp/setup.sh
#
# Refer to the Admin Guide for the format of the set dsa command.

set dsa $dsaname = 
{
     prefix        = <dc ca><dc $dsaname>
     dsa-name      = <dc ca><dc $dsaname><cn $dsaname>


     dsa-password  = "secret"
     address       = ipv4 $thishost port $dsaport

     disp-psap     = DISP
     snmp-port     = $dsaport
     console-port  = $consoleport
     auth-levels   = anonymous, clear-password, ssl-auth
     trust-flags   = allow-check-password, trust-conveyed-originator
};

EOF

    echo "   $dsaname knowledge file written"
    echo "   Moving the $dsaname knowledge file to the knowledge directory..."
    mv $dsaname.dxc $DXHOME/config/knowledge

    echo
    echo " Completed - $dsaname knowledge file configured"
    echo
    if [ "$quiet" = "n" ]; then
        echo Press RETURN to continue . . .
        read TMP 
    fi

    #clear
    echo
    echo " Configuring the $dsaname limits file"
    echo " --------------------------------------------"
    echo
    echo "   The $dsaname limits file $dsaname.dxc resides in the directory:"
    echo
    echo "     $DXHOME/config/limits/"
    echo
    echo "   Writing the $dsaname limits file..."

    rm -f $dsaname.dxc
    cat << EOF > $dsaname.dxc
# CA Technologies DXserver/config/limits
#
# $dsaname.dxc written by script based on samples/democorp/setup.sh
#
# SiteMinder Policy Store limits file.
#

# size limits
set max-users = 1000;
set credits = 5;
set max-local-ops = 1000;
set max-op-size = 40000;
set multi-write-queue = 20000;

# time limits
set max-bind-time = none;
set bind-idle-time = 3600;
set max-op-time = 600;

EOF

    echo "   $dsaname initialization file written"
    echo "   Moving the $dsaname limits file to the servers directory..."
    mv $dsaname.dxc $DXHOME/config/limits/
    echo
    echo " Completed - $dsaname limits file configured"
    echo
    if [ "$quiet" = "n" ]; then
        echo Press RETURN to continue . . .
        read TMP 
    fi	
	
#
# Write the DSA data files
#
 
    #clear
    echo
    echo " Creating/clearing the $dsaname database file '$dsaname' using dxemptydb"
    echo " -----------------------------------------------------------------------"
    echo
    dxemptydb $dsaname
    if [ $? -ne 0 ]; then
        fail dxemptydb
    fi
    echo
    echo " Completed - Database file creation "
    echo

    if [ "$quiet" = "n" ]; then
        echo Press RETURN to continue . . .
        read TMP 
    fi

#
# Load the base tree structure
#
	
#clear
echo
echo " Bulk load the $dsaname LDIF data into the Directory"
echo " ---------------------------------------------------"
echo
echo "   The dxloaddb tool is used to bulk load the LDIF data into the Directory"
echo
echo "   Bulk loading the LDIF file direct into $dsaname directory"
dxloaddb $dsaname $dsaname.ldi
if [ $? -ne 0 ]; then
    fail dxloaddb
fi

echo
echo " Completed - $dsaname Data Loaded"
echo
if [ "$quiet" = "n" ]; then
    echo Press RETURN to continue . . .
    read TMP
fi

#
# Start the DSA before exiting
#

#clear
echo
echo " Start the $dsaname before exiting the script"
echo " --------------------------------------------------------------"
echo

dxserver install $dsaname >/dev/null 2>&1
if [ $? -ne 0 ]; then
    fail dxserver.install
fi

dxserver start $dsaname
if [ $? -ne 0 ]; then
    fail dxserver.start
fi

echo
echo "  $dsaname sample CA Directory configuration complete." | tee /tmp/status 
echo

exit 0
